@@ -1,10 +1,14 @@
 from exabel_data_sdk.client.api.api_client.entity_api_client import EntityApiClient
+from exabel_data_sdk.client.api.api_client.exabel_api_group import ExabelApiGroup
 from exabel_data_sdk.client.api.api_client.grpc.base_grpc_client import BaseGrpcClient
 from exabel_data_sdk.client.api.error_handler import handle_grpc_error
 from exabel_data_sdk.client.client_config import ClientConfig
 from exabel_data_sdk.stubs.exabel.api.data.v1.all_pb2 import (
     CreateEntityRequest,
+    CreateEntityTypeRequest,
+    DeleteEntitiesRequest,
     DeleteEntityRequest,
+    DeleteEntityTypeRequest,
     Entity,
     EntityType,
     GetEntityRequest,
@@ -16,6 +20,7 @@ from exabel_data_sdk.stubs.exabel.api.data.v1.all_pb2 import (
     SearchEntitiesRequest,
     SearchEntitiesResponse,
     UpdateEntityRequest,
+    UpdateEntityTypeRequest,
 )
 from exabel_data_sdk.stubs.exabel.api.data.v1.all_pb2_grpc import EntityServiceStub
 
@@ -26,7 +31,7 @@ class EntityGrpcClient(EntityApiClient, BaseGrpcClient):
     """
 
     def __init__(self, config: ClientConfig):
-        super().__init__(config)
+        super().__init__(config, ExabelApiGroup.DATA_API)
         self.stub = EntityServiceStub(self.channel)
 
     @handle_grpc_error
@@ -39,6 +44,22 @@ class EntityGrpcClient(EntityApiClient, BaseGrpcClient):
     def get_entity_type(self, request: GetEntityTypeRequest) -> EntityType:
         return self.stub.GetEntityType(request, metadata=self.metadata, timeout=self.config.timeout)
 
+    @handle_grpc_error
+    def create_entity_type(self, request: CreateEntityTypeRequest) -> EntityType:
+        return self.stub.CreateEntityType(
+            request, metadata=self.metadata, timeout=self.config.timeout
+        )
+
+    @handle_grpc_error
+    def update_entity_type(self, request: UpdateEntityTypeRequest) -> EntityType:
+        return self.stub.UpdateEntityType(
+            request, metadata=self.metadata, timeout=self.config.timeout
+        )
+
+    @handle_grpc_error
+    def delete_entity_type(self, request: DeleteEntityTypeRequest) -> None:
+        self.stub.DeleteEntityType(request, metadata=self.metadata, timeout=self.config.timeout)
+
     @handle_grpc_error
     def list_entities(self, request: ListEntitiesRequest) -> ListEntitiesResponse:
         return self.stub.ListEntities(request, metadata=self.metadata, timeout=self.config.timeout)
@@ -59,6 +80,10 @@ class EntityGrpcClient(EntityApiClient, BaseGrpcClient):
     def delete_entity(self, request: DeleteEntityRequest) -> None:
         self.stub.DeleteEntity(request, metadata=self.metadata, timeout=self.config.timeout)
 
+    @handle_grpc_error
+    def delete_entities(self, request: DeleteEntitiesRequest) -> None:
+        self.stub.DeleteEntities(request, metadata=self.metadata, timeout=self.config.timeout)
+
     @handle_grpc_error
     def search_entities(self, request: SearchEntitiesRequest) -> SearchEntitiesResponse:
         return self.stub.SearchEntities(
