@@ -1,3 +1,4 @@
+from exabel_data_sdk.client.api.api_client.exabel_api_group import ExabelApiGroup
 from exabel_data_sdk.client.api.api_client.grpc.base_grpc_client import BaseGrpcClient
 from exabel_data_sdk.client.api.api_client.relationship_api_client import RelationshipApiClient
 from exabel_data_sdk.client.api.error_handler import handle_grpc_error
@@ -27,7 +28,7 @@ class RelationshipGrpcClient(RelationshipApiClient, BaseGrpcClient):
     """
 
     def __init__(self, config: ClientConfig):
-        super().__init__(config)
+        super().__init__(config, ExabelApiGroup.DATA_API)
         self.stub = RelationshipServiceStub(self.channel)
 
     @handle_grpc_error
