@@ -1,6 +1,8 @@
+from exabel_data_sdk.client.api.api_client.exabel_api_group import ExabelApiGroup
 from exabel_data_sdk.client.api.api_client.http.base_http_client import BaseHttpClient
 from exabel_data_sdk.client.api.api_client.relationship_api_client import RelationshipApiClient
 from exabel_data_sdk.client.api.data_classes.request_error import ErrorType, RequestError
+from exabel_data_sdk.client.client_config import ClientConfig
 from exabel_data_sdk.stubs.exabel.api.data.v1.all_pb2 import (
     CreateRelationshipRequest,
     CreateRelationshipTypeRequest,
@@ -21,9 +23,12 @@ from exabel_data_sdk.stubs.exabel.api.data.v1.all_pb2 import (
 
 class RelationshipHttpClient(RelationshipApiClient, BaseHttpClient):
     """
-    Client which sends relationship requests to the Exabel Data API with JSON over gRPC.
+    Client which sends relationship requests to the Exabel Data API with JSON over HTTP.
     """
 
+    def __init__(self, config: ClientConfig):
+        super().__init__(config, ExabelApiGroup.DATA_API)
+
     def list_relationship_types(
         self, request: ListRelationshipTypesRequest
     ) -> ListRelationshipTypesResponse:
