@@ -1,5 +1,7 @@
+from exabel_data_sdk.client.api.api_client.exabel_api_group import ExabelApiGroup
 from exabel_data_sdk.client.api.api_client.http.base_http_client import BaseHttpClient
 from exabel_data_sdk.client.api.api_client.signal_api_client import SignalApiClient
+from exabel_data_sdk.client.client_config import ClientConfig
 from exabel_data_sdk.stubs.exabel.api.data.v1.all_pb2 import (
     CreateSignalRequest,
     DeleteSignalRequest,
@@ -13,9 +15,12 @@ from exabel_data_sdk.stubs.exabel.api.data.v1.all_pb2 import (
 
 class SignalHttpClient(SignalApiClient, BaseHttpClient):
     """
-    Client which sends signal requests to the Exabel Data API with JSON over gRPC.
+    Client which sends signal requests to the Exabel Data API with JSON over HTTP.
     """
 
+    def __init__(self, config: ClientConfig):
+        super().__init__(config, ExabelApiGroup.DATA_API)
+
     def list_signals(self, request: ListSignalsRequest) -> ListSignalsResponse:
         return self._request("GET", "signals", ListSignalsResponse(), body=request)
 
