@@ -5,6 +5,8 @@ from exabel_data_sdk.stubs.exabel.api.data.v1.all_pb2 import (
     CreateTimeSeriesRequest,
     DeleteTimeSeriesRequest,
     GetTimeSeriesRequest,
+    ImportTimeSeriesRequest,
+    ImportTimeSeriesResponse,
     ListTimeSeriesRequest,
     ListTimeSeriesResponse,
     TimeSeries,
@@ -33,6 +35,10 @@ class TimeSeriesApiClient(ABC):
     def update_time_series(self, request: UpdateTimeSeriesRequest) -> TimeSeries:
         """Update a time series."""
 
+    @abstractmethod
+    def import_time_series(self, request: ImportTimeSeriesRequest) -> ImportTimeSeriesResponse:
+        """Import multiple time series."""
+
     @abstractmethod
     def delete_time_series(self, request: DeleteTimeSeriesRequest) -> None:
         """Delete a time series."""
