@@ -1,3 +1,4 @@
+import re
 from typing import Mapping, Union
 
 from exabel_data_sdk.client.api.proto_utils import from_struct, to_struct
@@ -26,8 +27,8 @@ class Entity:
         self,
         name: str,
         display_name: str,
-        description: str,
-        properties: Mapping[str, Union[str, bool, int, float]],
+        description: str = "",
+        properties: Mapping[str, Union[str, bool, int, float]] = None,
         read_only: bool = False,
     ):
         r"""
@@ -49,7 +50,7 @@ class Entity:
         self.name = name
         self.display_name = display_name
         self.description = description
-        self.properties = properties
+        self.properties = {} if properties is None else properties
         self.read_only = read_only
 
     @staticmethod
@@ -89,3 +90,16 @@ class Entity:
             f"description='{self.description}', properties={self.properties}, "
             f"read_only={self.read_only})"
         )
+
+    def __lt__(self, other: object) -> bool:
+        if not isinstance(other, Entity):
+            raise ValueError(f"Cannot compare Entity to non-Entity: {other}")
+        return self.name < other.name
+
+    def get_entity_type(self) -> str:
+        """Extracts the entity type name from the entity's resource name."""
+        p = re.compile(r"(entityTypes/[a-zA-Z0-9_\-.]+)/entities/[a-zA-Z0-9_\-.]+")
+        m = p.match(self.name)
+        if m:
+            return m.group(1)
+        raise ValueError(f"Could not parse entity resource name: {self.name}")
