@@ -6,15 +6,16 @@ class EntityType:
     An entity type resource in the Data API.
 
     Attributes:
-        name (str):         The resource name of the entity type, for example
-                            "entityTypes/entityTypeIdentifier" or
-                            "entityTypes/namespace.entityTypeIdentifier". The namespace must be
-                            empty (being global) or one of the predetermined namespaces the customer
-                            has access to. The entity type identifier must match the regex
-                            [a-zA-Z][\w-]{0,63}.
-        display_name (str): The display name of the entity type.
-        description (str):  One or more paragraphs of text description.
-        read_only (bool):   Whether this resource is read only.
+        name (str):             The resource name of the entity type, for example
+                                "entityTypes/entityTypeIdentifier" or
+                                "entityTypes/namespace.entityTypeIdentifier". The namespace must be
+                                empty (being global) or one of the predetermined namespaces the
+                                customer has access to. The entity type identifier must match the
+                                regex [a-zA-Z][\w-]{0,63}.
+        display_name (str):     The display name of the entity type.
+        description (str):      One or more paragraphs of text description.
+        read_only (bool):       Whether this resource is read only.
+        is_associative (bool):  Whether this entity type is associative.
     """
 
     def __init__(
@@ -23,6 +24,7 @@ class EntityType:
         display_name: str,
         description: str,
         read_only: bool = False,
+        is_associative: bool = False,
     ):
         r"""
         Create an entity type resource in the Data API.
@@ -42,6 +44,7 @@ class EntityType:
         self.display_name = display_name
         self.description = description
         self.read_only = read_only
+        self.is_associative = is_associative
 
     @staticmethod
     def from_proto(entity_type: ProtoEntityType) -> "EntityType":
@@ -51,6 +54,17 @@ class EntityType:
             display_name=entity_type.display_name,
             description=entity_type.description,
             read_only=entity_type.read_only,
+            is_associative=entity_type.is_associative,
+        )
+
+    def to_proto(self) -> ProtoEntityType:
+        """Create a protobuf EntityType from an EntityType."""
+        return ProtoEntityType(
+            name=self.name,
+            display_name=self.display_name,
+            description=self.description,
+            read_only=self.read_only,
+            is_associative=self.is_associative,
         )
 
     def __eq__(self, other: object) -> bool:
@@ -61,10 +75,12 @@ class EntityType:
             and self.display_name == other.display_name
             and self.description == other.description
             and self.read_only == other.read_only
+            and self.is_associative == other.is_associative
         )
 
     def __repr__(self) -> str:
         return (
             f"EntityType(name='{self.name}', display_name='{self.display_name}', "
-            f"description='{self.description}', read_only={self.read_only})"
+            f"description='{self.description}', read_only={self.read_only}, "
+            f"is_associative={self.is_associative})"
         )
