@@ -8,7 +8,7 @@ def from_struct(struct: Struct) -> Mapping[str, Union[str, bool, int, float]]:
     Convert a protobuf Struct into a Dict.
     """
     for value in struct.values():
-        if not isinstance(value, (str, bool, int, float)):
+        if not isinstance(value, (str, bool, int, float, type(None))):
             raise ValueError(f"Struct contains unsupported value: {value}")
     return dict(struct.items())
 
