@@ -8,4 +8,4 @@ from exabel_data_sdk.scripts.list_entities import ListEntities
 from exabel_data_sdk.scripts.list_entity_types import ListEntityTypes
 from exabel_data_sdk.scripts.list_relationship_types import ListRelationshipTypes
 from exabel_data_sdk.scripts.list_signals import ListSignals
-from exabel_data_sdk.scripts.load_time_series_from_csv import LoadTimeSeriesFromCsv
+from exabel_data_sdk.scripts.load_time_series_from_file import LoadTimeSeriesFromFile
